@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 #
-# Generated Mon Apr  6 17:26:12 2020 by generateDS.py version 2.35.17.
-# Python 2.7.5 (default, Aug  7 2019, 00:51:29)  [GCC 4.8.5 20150623 (Red Hat 4.8.5-39)]
+# Generated Tue May  5 18:41:56 2020 by generateDS.py version 2.35.21.
+# Python 2.7.5 (default, Apr  2 2020, 13:16:51)  [GCC 4.8.5 20150623 (Red Hat 4.8.5-39)]
 #
 # Command line options:
 #   ('-q', '')
@@ -17,7 +17,7 @@
 #   ../../../share/doc/xsd/index.xsd
 #
 # Command line:
-#   /root/init-build-jenkins.wEOlSo/opennebula-5.10.4/src/oca/python/bin/generateDS -q -f -o "pyone/bindings/supbind.py" -s "pyone/bindings/__init__.py" --super="supbind" --external-encoding="utf-8" --silence ../../../share/doc/xsd/index.xsd
+#   /root/init-build-jenkins.8OkOJ8/opennebula-5.10.5/src/oca/python/bin/generateDS -q -f -o "pyone/bindings/supbind.py" -s "pyone/bindings/__init__.py" --super="supbind" --external-encoding="utf-8" --silence ../../../share/doc/xsd/index.xsd
 #
 # Current working directory (os.getcwd()):
 #   python
@@ -312,6 +312,13 @@ supermod.ZONE.subclass = ZONESub
 # end class ZONESub
 
 
+class SHOWBACK_RECORDSSub(TemplatedType, supermod.SHOWBACK_RECORDS):
+    def __init__(self, SHOWBACK=None, **kwargs_):
+        super(SHOWBACK_RECORDSSub, self).__init__(SHOWBACK,  **kwargs_)
+supermod.SHOWBACK_RECORDS.subclass = SHOWBACK_RECORDSSub
+# end class SHOWBACK_RECORDSSub
+
+
 class VMTypeSub(TemplatedType, supermod.VMType):
     def __init__(self, ID=None, UID=None, GID=None, UNAME=None, GNAME=None, NAME=None, PERMISSIONS=None, LAST_POLL=None, STATE=None, LCM_STATE=None, PREV_STATE=None, PREV_LCM_STATE=None, RESCHED=None, STIME=None, ETIME=None, DEPLOY_ID=None, MONITORING=None, TEMPLATE=None, USER_TEMPLATE=None, HISTORY_RECORDS=None, SNAPSHOTS=None, **kwargs_):
         super(VMTypeSub, self).__init__(ID, UID, GID, UNAME, GNAME, NAME, PERMISSIONS, LAST_POLL, STATE, LCM_STATE, PREV_STATE, PREV_LCM_STATE, RESCHED, STIME, ETIME, DEPLOY_ID, MONITORING, TEMPLATE, USER_TEMPLATE, HISTORY_RECORDS, SNAPSHOTS,  **kwargs_)
@@ -1572,6 +1579,13 @@ supermod.SERVERType120.subclass = SERVERType120Sub
 # end class SERVERType120Sub
 
 
+class SHOWBACKTypeSub(TemplatedType, supermod.SHOWBACKType):
+    def __init__(self, VMID=None, VMNAME=None, UID=None, GID=None, UNAME=None, GNAME=None, YEAR=None, MONTH=None, CPU_COST=None, MEMORY_COST=None, DISK_COST=None, TOTAL_COST=None, HOURS=None, **kwargs_):
+        super(SHOWBACKTypeSub, self).__init__(VMID, VMNAME, UID, GID, UNAME, GNAME, YEAR, MONTH, CPU_COST, MEMORY_COST, DISK_COST, TOTAL_COST, HOURS,  **kwargs_)
+supermod.SHOWBACKType.subclass = SHOWBACKTypeSub
+# end class SHOWBACKTypeSub
+
+
 def get_root_tag(node):
     tag = supermod.Tag_pattern_.match(node.tag).groups()[-1]
     rootClass = None
